#!/usr/bin/perl

use v5.10.1;

say "@ARGV";
